# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InvoiceAddressResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'address': 'str',
        'apt_no': 'str',
        'floor': 'str',
        'door_no': 'str'
    }

    attribute_map = {
        'id': 'id',
        'address': 'address',
        'apt_no': 'aptNo',
        'floor': 'floor',
        'door_no': 'doorNo'
    }

    def __init__(self, id=None, address=None, apt_no=None, floor=None, door_no=None):  # noqa: E501
        """InvoiceAddressResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._address = None
        self._apt_no = None
        self._floor = None
        self._door_no = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if address is not None:
            self.address = address
        if apt_no is not None:
            self.apt_no = apt_no
        if floor is not None:
            self.floor = floor
        if door_no is not None:
            self.door_no = door_no

    @property
    def id(self):
        """Gets the id of this InvoiceAddressResponse.  # noqa: E501


        :return: The id of this InvoiceAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InvoiceAddressResponse.


        :param id: The id of this InvoiceAddressResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def address(self):
        """Gets the address of this InvoiceAddressResponse.  # noqa: E501


        :return: The address of this InvoiceAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this InvoiceAddressResponse.


        :param address: The address of this InvoiceAddressResponse.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def apt_no(self):
        """Gets the apt_no of this InvoiceAddressResponse.  # noqa: E501


        :return: The apt_no of this InvoiceAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._apt_no

    @apt_no.setter
    def apt_no(self, apt_no):
        """Sets the apt_no of this InvoiceAddressResponse.


        :param apt_no: The apt_no of this InvoiceAddressResponse.  # noqa: E501
        :type: str
        """

        self._apt_no = apt_no

    @property
    def floor(self):
        """Gets the floor of this InvoiceAddressResponse.  # noqa: E501


        :return: The floor of this InvoiceAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._floor

    @floor.setter
    def floor(self, floor):
        """Sets the floor of this InvoiceAddressResponse.


        :param floor: The floor of this InvoiceAddressResponse.  # noqa: E501
        :type: str
        """

        self._floor = floor

    @property
    def door_no(self):
        """Gets the door_no of this InvoiceAddressResponse.  # noqa: E501


        :return: The door_no of this InvoiceAddressResponse.  # noqa: E501
        :rtype: str
        """
        return self._door_no

    @door_no.setter
    def door_no(self, door_no):
        """Sets the door_no of this InvoiceAddressResponse.


        :param door_no: The door_no of this InvoiceAddressResponse.  # noqa: E501
        :type: str
        """

        self._door_no = door_no

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvoiceAddressResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceAddressResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class ProductsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_batch_request_result(self, batch_request_id, **kwargs):  # noqa: E501
        """Get products update result with using batchRequestId  # noqa: E501

        By using this service, the product's price and quantity are updated in groups of 1000. This method supports single and multiple items in a single request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_batch_request_result(batch_request_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str batch_request_id: (required)
        :return: ApiResponsePriceAndQuantityBatchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_batch_request_result_with_http_info(batch_request_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_batch_request_result_with_http_info(batch_request_id, **kwargs)  # noqa: E501
            return data

    def get_batch_request_result_with_http_info(self, batch_request_id, **kwargs):  # noqa: E501
        """Get products update result with using batchRequestId  # noqa: E501

        By using this service, the product's price and quantity are updated in groups of 1000. This method supports single and multiple items in a single request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_batch_request_result_with_http_info(batch_request_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str batch_request_id: (required)
        :return: ApiResponsePriceAndQuantityBatchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['batch_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_batch_request_result" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'batch_request_id' is set
        if ('batch_request_id' not in params or
                params['batch_request_id'] is None):
            raise ValueError("Missing the required parameter `batch_request_id` when calling `get_batch_request_result`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'batch_request_id' in params:
            path_params['batchRequestId'] = params['batch_request_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/products/price-and-quantity/batch-requests/{batchRequestId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponsePriceAndQuantityBatchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_chain_products(self, page, page_size, **kwargs):  # noqa: E501
        """Product integration allows you to list information such as stock, price, brand of seller's listings.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chain_products(page, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: (required)
        :param int page_size: (required)
        :return: PageableResponseSupplierProductResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_chain_products_with_http_info(page, page_size, **kwargs)  # noqa: E501
        else:
            (data) = self.get_chain_products_with_http_info(page, page_size, **kwargs)  # noqa: E501
            return data

    def get_chain_products_with_http_info(self, page, page_size, **kwargs):  # noqa: E501
        """Product integration allows you to list information such as stock, price, brand of seller's listings.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chain_products_with_http_info(page, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: (required)
        :param int page_size: (required)
        :return: PageableResponseSupplierProductResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_chain_products" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_chain_products`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_chain_products`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/products', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageableResponseSupplierProductResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_chain_productsby_chain_id(self, chain_id, page, page_size, **kwargs):  # noqa: E501
        """This method is used to get products by chain id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chain_productsby_chain_id(chain_id, page, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: (required)
        :param int page: (required)
        :param int page_size: (required)
        :return: PageableResponseSupplierProductResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_chain_productsby_chain_id_with_http_info(chain_id, page, page_size, **kwargs)  # noqa: E501
        else:
            (data) = self.get_chain_productsby_chain_id_with_http_info(chain_id, page, page_size, **kwargs)  # noqa: E501
            return data

    def get_chain_productsby_chain_id_with_http_info(self, chain_id, page, page_size, **kwargs):  # noqa: E501
        """This method is used to get products by chain id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_chain_productsby_chain_id_with_http_info(chain_id, page, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str chain_id: (required)
        :param int page: (required)
        :param int page_size: (required)
        :return: PageableResponseSupplierProductResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['chain_id', 'page', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_chain_productsby_chain_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'chain_id' is set
        if ('chain_id' not in params or
                params['chain_id'] is None):
            raise ValueError("Missing the required parameter `chain_id` when calling `get_chain_productsby_chain_id`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_chain_productsby_chain_id`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_chain_productsby_chain_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'chain_id' in params:
            path_params['chainId'] = params['chain_id']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/chains/{chainId}/products', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageableResponseSupplierProductResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_shop_productsby_shop_id(self, shop_id, page, page_size, **kwargs):  # noqa: E501
        """This method is used to get products by shop id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_shop_productsby_shop_id(shop_id, page, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shop_id: (required)
        :param int page: (required)
        :param int page_size: (required)
        :return: ApiResponsePageableResponseShopProductsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_shop_productsby_shop_id_with_http_info(shop_id, page, page_size, **kwargs)  # noqa: E501
        else:
            (data) = self.get_shop_productsby_shop_id_with_http_info(shop_id, page, page_size, **kwargs)  # noqa: E501
            return data

    def get_shop_productsby_shop_id_with_http_info(self, shop_id, page, page_size, **kwargs):  # noqa: E501
        """This method is used to get products by shop id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_shop_productsby_shop_id_with_http_info(shop_id, page, page_size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shop_id: (required)
        :param int page: (required)
        :param int page_size: (required)
        :return: ApiResponsePageableResponseShopProductsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['shop_id', 'page', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_shop_productsby_shop_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `get_shop_productsby_shop_id`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_shop_productsby_shop_id`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_shop_productsby_shop_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/shops/{shopId}/products', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponsePageableResponseShopProductsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_price_and_quantity(self, body, **kwargs):  # noqa: E501
        """Update price and quantity of products  # noqa: E501

        This method is used for updating price and quantity information of approved products. You can send stock and price information separately on request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_price_and_quantity(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProductBatchRequest body: (required)
        :return: ApiResponseProductBatchTicketResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_price_and_quantity_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_price_and_quantity_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def update_price_and_quantity_with_http_info(self, body, **kwargs):  # noqa: E501
        """Update price and quantity of products  # noqa: E501

        This method is used for updating price and quantity information of approved products. You can send stock and price information separately on request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_price_and_quantity_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProductBatchRequest body: (required)
        :return: ApiResponseProductBatchTicketResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_price_and_quantity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_price_and_quantity`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/products/price-and-quantity', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseProductBatchTicketResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApiResponsePageableResponseShopProductsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'meta': 'OperationResult',
        'data': 'ApiResponsePageableResponseShopProductsResponseData'
    }

    attribute_map = {
        'meta': 'meta',
        'data': 'data'
    }

    def __init__(self, meta=None, data=None):  # noqa: E501
        """ApiResponsePageableResponseShopProductsResponse - a model defined in Swagger"""  # noqa: E501
        self._meta = None
        self._data = None
        self.discriminator = None
        if meta is not None:
            self.meta = meta
        if data is not None:
            self.data = data

    @property
    def meta(self):
        """Gets the meta of this ApiResponsePageableResponseShopProductsResponse.  # noqa: E501


        :return: The meta of this ApiResponsePageableResponseShopProductsResponse.  # noqa: E501
        :rtype: OperationResult
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this ApiResponsePageableResponseShopProductsResponse.


        :param meta: The meta of this ApiResponsePageableResponseShopProductsResponse.  # noqa: E501
        :type: OperationResult
        """

        self._meta = meta

    @property
    def data(self):
        """Gets the data of this ApiResponsePageableResponseShopProductsResponse.  # noqa: E501


        :return: The data of this ApiResponsePageableResponseShopProductsResponse.  # noqa: E501
        :rtype: ApiResponsePageableResponseShopProductsResponseData
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ApiResponsePageableResponseShopProductsResponse.


        :param data: The data of this ApiResponsePageableResponseShopProductsResponse.  # noqa: E501
        :type: ApiResponsePageableResponseShopProductsResponseData
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiResponsePageableResponseShopProductsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiResponsePageableResponseShopProductsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import swagger_client
from swagger_client import Configuration, ApiClient, AuthApi, ShopsApi, SupplierApi

# configuration

configuration = Configuration()
configuration.username="orucmarket"
configuration.password="Oruc123*"
configuration.host="https://locals-integration-api-gateway.artisan.getirapi.com"
api_client = ApiClient(configuration=configuration)
api_instance = AuthApi(api_client=api_client)
sup = SupplierApi(api_client=api_client)
ShopsApi(api_client=api_client)

# get token

token = api_instance.login()
api_client.default_headers["Authorization"] = "Bearer " + token.data.token
supplier = sup.get_supplier()

#print(supplier)
chainList=supplier.data.chains
chainlist=[]
for chain in chainList:
    chainlist.append(chain.id)

print(chainlist)

api_client.default_headers["Authorization"] = "Bearer " + "sa"

supplier = sup.get_supplier()



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OrderResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'order_id': 'str',
        'order_type': 'str',
        'confirmation_id': 'str',
        'shop_id': 'str',
        'supplier_id': 'str',
        'max_possible_amount_merchant_can_charge': 'float',
        'min_possible_amount_merchant_can_charge': 'float',
        'is_promo_applied': 'bool',
        'client_note': 'str',
        'client_batched_note': 'str',
        'do_not_knock': 'bool',
        'total_price': 'float',
        'checkout_date': 'str',
        'delivery_type': 'int',
        'payment_method': 'int',
        'payment_method_text': 'PaymentMethodTextResponse',
        'customer': 'CustomerResponse',
        'invoice_address': 'InvoiceAddressResponse',
        'products': 'list[ProductResponse]'
    }

    attribute_map = {
        'order_id': 'orderID',
        'order_type': 'orderType',
        'confirmation_id': 'confirmationId',
        'shop_id': 'shopID',
        'supplier_id': 'supplierID',
        'max_possible_amount_merchant_can_charge': 'maxPossibleAmountMerchantCanCharge',
        'min_possible_amount_merchant_can_charge': 'minPossibleAmountMerchantCanCharge',
        'is_promo_applied': 'isPromoApplied',
        'client_note': 'clientNote',
        'client_batched_note': 'clientBatchedNote',
        'do_not_knock': 'doNotKnock',
        'total_price': 'totalPrice',
        'checkout_date': 'checkoutDate',
        'delivery_type': 'deliveryType',
        'payment_method': 'paymentMethod',
        'payment_method_text': 'paymentMethodText',
        'customer': 'customer',
        'invoice_address': 'invoiceAddress',
        'products': 'products'
    }

    def __init__(self, order_id=None, order_type=None, confirmation_id=None, shop_id=None, supplier_id=None, max_possible_amount_merchant_can_charge=None, min_possible_amount_merchant_can_charge=None, is_promo_applied=None, client_note=None, client_batched_note=None, do_not_knock=None, total_price=None, checkout_date=None, delivery_type=None, payment_method=None, payment_method_text=None, customer=None, invoice_address=None, products=None):  # noqa: E501
        """OrderResponse - a model defined in Swagger"""  # noqa: E501
        self._order_id = None
        self._order_type = None
        self._confirmation_id = None
        self._shop_id = None
        self._supplier_id = None
        self._max_possible_amount_merchant_can_charge = None
        self._min_possible_amount_merchant_can_charge = None
        self._is_promo_applied = None
        self._client_note = None
        self._client_batched_note = None
        self._do_not_knock = None
        self._total_price = None
        self._checkout_date = None
        self._delivery_type = None
        self._payment_method = None
        self._payment_method_text = None
        self._customer = None
        self._invoice_address = None
        self._products = None
        self.discriminator = None
        if order_id is not None:
            self.order_id = order_id
        if order_type is not None:
            self.order_type = order_type
        if confirmation_id is not None:
            self.confirmation_id = confirmation_id
        if shop_id is not None:
            self.shop_id = shop_id
        if supplier_id is not None:
            self.supplier_id = supplier_id
        if max_possible_amount_merchant_can_charge is not None:
            self.max_possible_amount_merchant_can_charge = max_possible_amount_merchant_can_charge
        if min_possible_amount_merchant_can_charge is not None:
            self.min_possible_amount_merchant_can_charge = min_possible_amount_merchant_can_charge
        if is_promo_applied is not None:
            self.is_promo_applied = is_promo_applied
        if client_note is not None:
            self.client_note = client_note
        if client_batched_note is not None:
            self.client_batched_note = client_batched_note
        if do_not_knock is not None:
            self.do_not_knock = do_not_knock
        if total_price is not None:
            self.total_price = total_price
        if checkout_date is not None:
            self.checkout_date = checkout_date
        if delivery_type is not None:
            self.delivery_type = delivery_type
        if payment_method is not None:
            self.payment_method = payment_method
        if payment_method_text is not None:
            self.payment_method_text = payment_method_text
        if customer is not None:
            self.customer = customer
        if invoice_address is not None:
            self.invoice_address = invoice_address
        if products is not None:
            self.products = products

    @property
    def order_id(self):
        """Gets the order_id of this OrderResponse.  # noqa: E501


        :return: The order_id of this OrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this OrderResponse.


        :param order_id: The order_id of this OrderResponse.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def order_type(self):
        """Gets the order_type of this OrderResponse.  # noqa: E501


        :return: The order_type of this OrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._order_type

    @order_type.setter
    def order_type(self, order_type):
        """Sets the order_type of this OrderResponse.


        :param order_type: The order_type of this OrderResponse.  # noqa: E501
        :type: str
        """

        self._order_type = order_type

    @property
    def confirmation_id(self):
        """Gets the confirmation_id of this OrderResponse.  # noqa: E501


        :return: The confirmation_id of this OrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._confirmation_id

    @confirmation_id.setter
    def confirmation_id(self, confirmation_id):
        """Sets the confirmation_id of this OrderResponse.


        :param confirmation_id: The confirmation_id of this OrderResponse.  # noqa: E501
        :type: str
        """

        self._confirmation_id = confirmation_id

    @property
    def shop_id(self):
        """Gets the shop_id of this OrderResponse.  # noqa: E501


        :return: The shop_id of this OrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._shop_id

    @shop_id.setter
    def shop_id(self, shop_id):
        """Sets the shop_id of this OrderResponse.


        :param shop_id: The shop_id of this OrderResponse.  # noqa: E501
        :type: str
        """

        self._shop_id = shop_id

    @property
    def supplier_id(self):
        """Gets the supplier_id of this OrderResponse.  # noqa: E501


        :return: The supplier_id of this OrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, supplier_id):
        """Sets the supplier_id of this OrderResponse.


        :param supplier_id: The supplier_id of this OrderResponse.  # noqa: E501
        :type: str
        """

        self._supplier_id = supplier_id

    @property
    def max_possible_amount_merchant_can_charge(self):
        """Gets the max_possible_amount_merchant_can_charge of this OrderResponse.  # noqa: E501


        :return: The max_possible_amount_merchant_can_charge of this OrderResponse.  # noqa: E501
        :rtype: float
        """
        return self._max_possible_amount_merchant_can_charge

    @max_possible_amount_merchant_can_charge.setter
    def max_possible_amount_merchant_can_charge(self, max_possible_amount_merchant_can_charge):
        """Sets the max_possible_amount_merchant_can_charge of this OrderResponse.


        :param max_possible_amount_merchant_can_charge: The max_possible_amount_merchant_can_charge of this OrderResponse.  # noqa: E501
        :type: float
        """

        self._max_possible_amount_merchant_can_charge = max_possible_amount_merchant_can_charge

    @property
    def min_possible_amount_merchant_can_charge(self):
        """Gets the min_possible_amount_merchant_can_charge of this OrderResponse.  # noqa: E501


        :return: The min_possible_amount_merchant_can_charge of this OrderResponse.  # noqa: E501
        :rtype: float
        """
        return self._min_possible_amount_merchant_can_charge

    @min_possible_amount_merchant_can_charge.setter
    def min_possible_amount_merchant_can_charge(self, min_possible_amount_merchant_can_charge):
        """Sets the min_possible_amount_merchant_can_charge of this OrderResponse.


        :param min_possible_amount_merchant_can_charge: The min_possible_amount_merchant_can_charge of this OrderResponse.  # noqa: E501
        :type: float
        """

        self._min_possible_amount_merchant_can_charge = min_possible_amount_merchant_can_charge

    @property
    def is_promo_applied(self):
        """Gets the is_promo_applied of this OrderResponse.  # noqa: E501


        :return: The is_promo_applied of this OrderResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_promo_applied

    @is_promo_applied.setter
    def is_promo_applied(self, is_promo_applied):
        """Sets the is_promo_applied of this OrderResponse.


        :param is_promo_applied: The is_promo_applied of this OrderResponse.  # noqa: E501
        :type: bool
        """

        self._is_promo_applied = is_promo_applied

    @property
    def client_note(self):
        """Gets the client_note of this OrderResponse.  # noqa: E501


        :return: The client_note of this OrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._client_note

    @client_note.setter
    def client_note(self, client_note):
        """Sets the client_note of this OrderResponse.


        :param client_note: The client_note of this OrderResponse.  # noqa: E501
        :type: str
        """

        self._client_note = client_note

    @property
    def client_batched_note(self):
        """Gets the client_batched_note of this OrderResponse.  # noqa: E501


        :return: The client_batched_note of this OrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._client_batched_note

    @client_batched_note.setter
    def client_batched_note(self, client_batched_note):
        """Sets the client_batched_note of this OrderResponse.


        :param client_batched_note: The client_batched_note of this OrderResponse.  # noqa: E501
        :type: str
        """

        self._client_batched_note = client_batched_note

    @property
    def do_not_knock(self):
        """Gets the do_not_knock of this OrderResponse.  # noqa: E501


        :return: The do_not_knock of this OrderResponse.  # noqa: E501
        :rtype: bool
        """
        return self._do_not_knock

    @do_not_knock.setter
    def do_not_knock(self, do_not_knock):
        """Sets the do_not_knock of this OrderResponse.


        :param do_not_knock: The do_not_knock of this OrderResponse.  # noqa: E501
        :type: bool
        """

        self._do_not_knock = do_not_knock

    @property
    def total_price(self):
        """Gets the total_price of this OrderResponse.  # noqa: E501


        :return: The total_price of this OrderResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_price

    @total_price.setter
    def total_price(self, total_price):
        """Sets the total_price of this OrderResponse.


        :param total_price: The total_price of this OrderResponse.  # noqa: E501
        :type: float
        """

        self._total_price = total_price

    @property
    def checkout_date(self):
        """Gets the checkout_date of this OrderResponse.  # noqa: E501


        :return: The checkout_date of this OrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._checkout_date

    @checkout_date.setter
    def checkout_date(self, checkout_date):
        """Sets the checkout_date of this OrderResponse.


        :param checkout_date: The checkout_date of this OrderResponse.  # noqa: E501
        :type: str
        """

        self._checkout_date = checkout_date

    @property
    def delivery_type(self):
        """Gets the delivery_type of this OrderResponse.  # noqa: E501


        :return: The delivery_type of this OrderResponse.  # noqa: E501
        :rtype: int
        """
        return self._delivery_type

    @delivery_type.setter
    def delivery_type(self, delivery_type):
        """Sets the delivery_type of this OrderResponse.


        :param delivery_type: The delivery_type of this OrderResponse.  # noqa: E501
        :type: int
        """

        self._delivery_type = delivery_type

    @property
    def payment_method(self):
        """Gets the payment_method of this OrderResponse.  # noqa: E501


        :return: The payment_method of this OrderResponse.  # noqa: E501
        :rtype: int
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this OrderResponse.


        :param payment_method: The payment_method of this OrderResponse.  # noqa: E501
        :type: int
        """

        self._payment_method = payment_method

    @property
    def payment_method_text(self):
        """Gets the payment_method_text of this OrderResponse.  # noqa: E501


        :return: The payment_method_text of this OrderResponse.  # noqa: E501
        :rtype: PaymentMethodTextResponse
        """
        return self._payment_method_text

    @payment_method_text.setter
    def payment_method_text(self, payment_method_text):
        """Sets the payment_method_text of this OrderResponse.


        :param payment_method_text: The payment_method_text of this OrderResponse.  # noqa: E501
        :type: PaymentMethodTextResponse
        """

        self._payment_method_text = payment_method_text

    @property
    def customer(self):
        """Gets the customer of this OrderResponse.  # noqa: E501


        :return: The customer of this OrderResponse.  # noqa: E501
        :rtype: CustomerResponse
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this OrderResponse.


        :param customer: The customer of this OrderResponse.  # noqa: E501
        :type: CustomerResponse
        """

        self._customer = customer

    @property
    def invoice_address(self):
        """Gets the invoice_address of this OrderResponse.  # noqa: E501


        :return: The invoice_address of this OrderResponse.  # noqa: E501
        :rtype: InvoiceAddressResponse
        """
        return self._invoice_address

    @invoice_address.setter
    def invoice_address(self, invoice_address):
        """Sets the invoice_address of this OrderResponse.


        :param invoice_address: The invoice_address of this OrderResponse.  # noqa: E501
        :type: InvoiceAddressResponse
        """

        self._invoice_address = invoice_address

    @property
    def products(self):
        """Gets the products of this OrderResponse.  # noqa: E501


        :return: The products of this OrderResponse.  # noqa: E501
        :rtype: list[ProductResponse]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this OrderResponse.


        :param products: The products of this OrderResponse.  # noqa: E501
        :type: list[ProductResponse]
        """

        self._products = products

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrderResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OrderDtoResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'order_id': 'str',
        'shop_id': 'str',
        'order_date': 'str',
        'cancel_source_code': 'float',
        'order_status_code': 'float',
        'order_total_price': 'float',
        'total_charged_amount_after_provision_or_refund': 'float'
    }

    attribute_map = {
        'order_id': 'orderId',
        'shop_id': 'shopId',
        'order_date': 'orderDate',
        'cancel_source_code': 'cancelSourceCode',
        'order_status_code': 'orderStatusCode',
        'order_total_price': 'orderTotalPrice',
        'total_charged_amount_after_provision_or_refund': 'totalChargedAmountAfterProvisionOrRefund'
    }

    def __init__(self, order_id=None, shop_id=None, order_date=None, cancel_source_code=None, order_status_code=None, order_total_price=None, total_charged_amount_after_provision_or_refund=None):  # noqa: E501
        """OrderDtoResponse - a model defined in Swagger"""  # noqa: E501
        self._order_id = None
        self._shop_id = None
        self._order_date = None
        self._cancel_source_code = None
        self._order_status_code = None
        self._order_total_price = None
        self._total_charged_amount_after_provision_or_refund = None
        self.discriminator = None
        if order_id is not None:
            self.order_id = order_id
        if shop_id is not None:
            self.shop_id = shop_id
        if order_date is not None:
            self.order_date = order_date
        if cancel_source_code is not None:
            self.cancel_source_code = cancel_source_code
        if order_status_code is not None:
            self.order_status_code = order_status_code
        if order_total_price is not None:
            self.order_total_price = order_total_price
        if total_charged_amount_after_provision_or_refund is not None:
            self.total_charged_amount_after_provision_or_refund = total_charged_amount_after_provision_or_refund

    @property
    def order_id(self):
        """Gets the order_id of this OrderDtoResponse.  # noqa: E501


        :return: The order_id of this OrderDtoResponse.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this OrderDtoResponse.


        :param order_id: The order_id of this OrderDtoResponse.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def shop_id(self):
        """Gets the shop_id of this OrderDtoResponse.  # noqa: E501


        :return: The shop_id of this OrderDtoResponse.  # noqa: E501
        :rtype: str
        """
        return self._shop_id

    @shop_id.setter
    def shop_id(self, shop_id):
        """Sets the shop_id of this OrderDtoResponse.


        :param shop_id: The shop_id of this OrderDtoResponse.  # noqa: E501
        :type: str
        """

        self._shop_id = shop_id

    @property
    def order_date(self):
        """Gets the order_date of this OrderDtoResponse.  # noqa: E501


        :return: The order_date of this OrderDtoResponse.  # noqa: E501
        :rtype: str
        """
        return self._order_date

    @order_date.setter
    def order_date(self, order_date):
        """Sets the order_date of this OrderDtoResponse.


        :param order_date: The order_date of this OrderDtoResponse.  # noqa: E501
        :type: str
        """

        self._order_date = order_date

    @property
    def cancel_source_code(self):
        """Gets the cancel_source_code of this OrderDtoResponse.  # noqa: E501


        :return: The cancel_source_code of this OrderDtoResponse.  # noqa: E501
        :rtype: float
        """
        return self._cancel_source_code

    @cancel_source_code.setter
    def cancel_source_code(self, cancel_source_code):
        """Sets the cancel_source_code of this OrderDtoResponse.


        :param cancel_source_code: The cancel_source_code of this OrderDtoResponse.  # noqa: E501
        :type: float
        """

        self._cancel_source_code = cancel_source_code

    @property
    def order_status_code(self):
        """Gets the order_status_code of this OrderDtoResponse.  # noqa: E501


        :return: The order_status_code of this OrderDtoResponse.  # noqa: E501
        :rtype: float
        """
        return self._order_status_code

    @order_status_code.setter
    def order_status_code(self, order_status_code):
        """Sets the order_status_code of this OrderDtoResponse.


        :param order_status_code: The order_status_code of this OrderDtoResponse.  # noqa: E501
        :type: float
        """

        self._order_status_code = order_status_code

    @property
    def order_total_price(self):
        """Gets the order_total_price of this OrderDtoResponse.  # noqa: E501


        :return: The order_total_price of this OrderDtoResponse.  # noqa: E501
        :rtype: float
        """
        return self._order_total_price

    @order_total_price.setter
    def order_total_price(self, order_total_price):
        """Sets the order_total_price of this OrderDtoResponse.


        :param order_total_price: The order_total_price of this OrderDtoResponse.  # noqa: E501
        :type: float
        """

        self._order_total_price = order_total_price

    @property
    def total_charged_amount_after_provision_or_refund(self):
        """Gets the total_charged_amount_after_provision_or_refund of this OrderDtoResponse.  # noqa: E501


        :return: The total_charged_amount_after_provision_or_refund of this OrderDtoResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_charged_amount_after_provision_or_refund

    @total_charged_amount_after_provision_or_refund.setter
    def total_charged_amount_after_provision_or_refund(self, total_charged_amount_after_provision_or_refund):
        """Sets the total_charged_amount_after_provision_or_refund of this OrderDtoResponse.


        :param total_charged_amount_after_provision_or_refund: The total_charged_amount_after_provision_or_refund of this OrderDtoResponse.  # noqa: E501
        :type: float
        """

        self._total_charged_amount_after_provision_or_refund = total_charged_amount_after_provision_or_refund

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrderDtoResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderDtoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class ShopsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_shop(self, shop_id, **kwargs):  # noqa: E501
        """It is used to get the shop informations.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_shop(shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shop_id: (required)
        :return: ApiResponseGetShopResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_shop_with_http_info(shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_shop_with_http_info(shop_id, **kwargs)  # noqa: E501
            return data

    def get_shop_with_http_info(self, shop_id, **kwargs):  # noqa: E501
        """It is used to get the shop informations.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_shop_with_http_info(shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str shop_id: (required)
        :return: ApiResponseGetShopResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['shop_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_shop" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `get_shop`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/shops/{shopId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseGetShopResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_shop_courier_working_status(self, body, shop_id, **kwargs):  # noqa: E501
        """It is used to put the shops couiers working status.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_shop_courier_working_status(body, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateShopCouriersStatusRequest body: (required)
        :param str shop_id: (required)
        :return: ApiResponseShopCouriersWorkingStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_shop_courier_working_status_with_http_info(body, shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_shop_courier_working_status_with_http_info(body, shop_id, **kwargs)  # noqa: E501
            return data

    def update_shop_courier_working_status_with_http_info(self, body, shop_id, **kwargs):  # noqa: E501
        """It is used to put the shops couiers working status.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_shop_courier_working_status_with_http_info(body, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateShopCouriersStatusRequest body: (required)
        :param str shop_id: (required)
        :return: ApiResponseShopCouriersWorkingStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'shop_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_shop_courier_working_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_shop_courier_working_status`")  # noqa: E501
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `update_shop_courier_working_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/shops/{shopId}/couriers/working-status', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseShopCouriersWorkingStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_shop_working_hours(self, body, shop_id, **kwargs):  # noqa: E501
        """It is used to put the shops working hours.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_shop_working_hours(body, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateShopWorkingHoursRequest body: (required)
        :param str shop_id: (required)
        :return: ApiResponseShopWorkingHoursResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_shop_working_hours_with_http_info(body, shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_shop_working_hours_with_http_info(body, shop_id, **kwargs)  # noqa: E501
            return data

    def update_shop_working_hours_with_http_info(self, body, shop_id, **kwargs):  # noqa: E501
        """It is used to put the shops working hours.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_shop_working_hours_with_http_info(body, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateShopWorkingHoursRequest body: (required)
        :param str shop_id: (required)
        :return: ApiResponseShopWorkingHoursResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'shop_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_shop_working_hours" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_shop_working_hours`")  # noqa: E501
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `update_shop_working_hours`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/shops/{shopId}/working-hours', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseShopWorkingHoursResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_shop_working_status(self, body, shop_id, **kwargs):  # noqa: E501
        """It is used to put the shops working status.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_shop_working_status(body, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateShopStatusRequest body: (required)
        :param str shop_id: (required)
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_shop_working_status_with_http_info(body, shop_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_shop_working_status_with_http_info(body, shop_id, **kwargs)  # noqa: E501
            return data

    def update_shop_working_status_with_http_info(self, body, shop_id, **kwargs):  # noqa: E501
        """It is used to put the shops working status.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_shop_working_status_with_http_info(body, shop_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateShopStatusRequest body: (required)
        :param str shop_id: (required)
        :return: ApiResponseObject
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'shop_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_shop_working_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_shop_working_status`")  # noqa: E501
        # verify the required parameter 'shop_id' is set
        if ('shop_id' not in params or
                params['shop_id'] is None):
            raise ValueError("Missing the required parameter `shop_id` when calling `update_shop_working_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'shop_id' in params:
            path_params['shopId'] = params['shop_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/v1/shops/{shopId}/working-status', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApiResponseObject',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Getir-Locals Integration Swagger Documentation

    This documentation is created by Getir Developers for Getir-Locals Integration.For this integration, you need to take CLIENT NAME and CLIENT SECRET keys from Getir-dev team and use these keys for authentication. You also need to use access token provided after successful login to be able to use all other endpoints  You can view information about the active order through /orders/unapproved endpoints. The status of the order is managed via verify, prepare, handover and cancel endpoints. Details on order management are as follows:  For orders to be made by the Getir courier, the flow is as follows:  Supplier confirms order --verify<br />Supplier prepares order --prepare (1-2 minutes must pass before delivery)<br />Supplier hands over the order to Getir courier --handover<br />For Getir delivery, transactions are made by the Getir courier after handover.  A valid reason will be requested from the supplier to cancel an order. Valid reasons may vary depending on the instant status of the order. For this reason, before canceling an order, you have to get instant valid order cancellation reasons from /orders/{orderId}/cancel-options endpoint.   # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ArtisanOrderResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'shop_id': 'str',
        'status': 'float',
        'total_price': 'float',
        'total_discount_amount': 'float',
        'order_number': 'str',
        'products': 'list[ProductResponse]'
    }

    attribute_map = {
        'id': 'id',
        'shop_id': 'shopId',
        'status': 'status',
        'total_price': 'totalPrice',
        'total_discount_amount': 'totalDiscountAmount',
        'order_number': 'orderNumber',
        'products': 'products'
    }

    def __init__(self, id=None, shop_id=None, status=None, total_price=None, total_discount_amount=None, order_number=None, products=None):  # noqa: E501
        """ArtisanOrderResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._shop_id = None
        self._status = None
        self._total_price = None
        self._total_discount_amount = None
        self._order_number = None
        self._products = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if shop_id is not None:
            self.shop_id = shop_id
        if status is not None:
            self.status = status
        if total_price is not None:
            self.total_price = total_price
        if total_discount_amount is not None:
            self.total_discount_amount = total_discount_amount
        if order_number is not None:
            self.order_number = order_number
        if products is not None:
            self.products = products

    @property
    def id(self):
        """Gets the id of this ArtisanOrderResponse.  # noqa: E501


        :return: The id of this ArtisanOrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ArtisanOrderResponse.


        :param id: The id of this ArtisanOrderResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def shop_id(self):
        """Gets the shop_id of this ArtisanOrderResponse.  # noqa: E501


        :return: The shop_id of this ArtisanOrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._shop_id

    @shop_id.setter
    def shop_id(self, shop_id):
        """Sets the shop_id of this ArtisanOrderResponse.


        :param shop_id: The shop_id of this ArtisanOrderResponse.  # noqa: E501
        :type: str
        """

        self._shop_id = shop_id

    @property
    def status(self):
        """Gets the status of this ArtisanOrderResponse.  # noqa: E501


        :return: The status of this ArtisanOrderResponse.  # noqa: E501
        :rtype: float
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ArtisanOrderResponse.


        :param status: The status of this ArtisanOrderResponse.  # noqa: E501
        :type: float
        """

        self._status = status

    @property
    def total_price(self):
        """Gets the total_price of this ArtisanOrderResponse.  # noqa: E501


        :return: The total_price of this ArtisanOrderResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_price

    @total_price.setter
    def total_price(self, total_price):
        """Sets the total_price of this ArtisanOrderResponse.


        :param total_price: The total_price of this ArtisanOrderResponse.  # noqa: E501
        :type: float
        """

        self._total_price = total_price

    @property
    def total_discount_amount(self):
        """Gets the total_discount_amount of this ArtisanOrderResponse.  # noqa: E501


        :return: The total_discount_amount of this ArtisanOrderResponse.  # noqa: E501
        :rtype: float
        """
        return self._total_discount_amount

    @total_discount_amount.setter
    def total_discount_amount(self, total_discount_amount):
        """Sets the total_discount_amount of this ArtisanOrderResponse.


        :param total_discount_amount: The total_discount_amount of this ArtisanOrderResponse.  # noqa: E501
        :type: float
        """

        self._total_discount_amount = total_discount_amount

    @property
    def order_number(self):
        """Gets the order_number of this ArtisanOrderResponse.  # noqa: E501


        :return: The order_number of this ArtisanOrderResponse.  # noqa: E501
        :rtype: str
        """
        return self._order_number

    @order_number.setter
    def order_number(self, order_number):
        """Sets the order_number of this ArtisanOrderResponse.


        :param order_number: The order_number of this ArtisanOrderResponse.  # noqa: E501
        :type: str
        """

        self._order_number = order_number

    @property
    def products(self):
        """Gets the products of this ArtisanOrderResponse.  # noqa: E501


        :return: The products of this ArtisanOrderResponse.  # noqa: E501
        :rtype: list[ProductResponse]
        """
        return self._products

    @products.setter
    def products(self, products):
        """Sets the products of this ArtisanOrderResponse.


        :param products: The products of this ArtisanOrderResponse.  # noqa: E501
        :type: list[ProductResponse]
        """

        self._products = products

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ArtisanOrderResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArtisanOrderResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
